package PureMessage::HTTPD::Services::Access;
use PureMessage::Resources::Location;
use strict;
use warnings;
use base 'Exporter';
use PureMessage::Resources::DBH qw(DBH);
our @EXPORT_OK = qw(ip_is_valid
                    get_all_machine_ips
                    get_machine_hostname_from_ip);


my %known_ips = (
    '127.0.0.1' => 1,
);

my $hostname_by_ip = { };

sub ip_is_valid {
    my $ip = shift;
    return $known_ips{$ip} if defined $known_ips{$ip};
    my $dbh = DBH();
    my $sql = 'select ip from cfg_location where ip = ?';
    my $sth = $dbh->prepare($sql);
    $sth->execute($ip);
    my $ar = $sth->fetchall_arrayref;
    my $ok = @$ar > 0 ? 1 : 0;
    return $known_ips{$ip} = $ok;
}

sub get_all_machine_ips {
    my $dbh = DBH();
    my $loc = PureMessage::Resources::Location->new();
    my $location_id = $loc->location_id;
    my $sql = "select ip from cfg_location";

    my $ar = $dbh->selectcol_arrayref($sql);
    return $ar;
}

sub get_machine_hostname_from_ip {
    my $ip = shift;
    return $hostname_by_ip->{$ip}->{hostname} if defined $hostname_by_ip->{$ip};
    my $dbh = DBH();
    my $sql = 'select ip,hostname from cfg_location';
    my $hostname_by_ip = $dbh->selectall_hashref($sql, 'ip');
    return $hostname_by_ip->{$ip}->{hostname} if defined $hostname_by_ip->{$ip};
}

1;
